@@ -1,28 +1,35 @@
 import logging, json
+from abc import ABC, abstractmethod
 
 from django.contrib.contenttypes.models import ContentType
 from django.forms import model_to_dict
 from django.http import Http404
 
 from django_glue.json import generate_json_response, generate_json_404_response
-from django_glue.utils import process_and_save_field_value, process_and_save_form_values, get_glue_session, \
-    decode_query_set_from_str, run_glue_method, glue_access_check, generate_simple_field_dict
+from django_glue.glue import glue_run_method, glue_access_check, get_glue_session
+from django_glue.utils import process_and_save_field_value, process_and_save_form_values, decode_query_set_from_str, \
+    generate_simple_field_dict
 from django_glue.conf import settings
 
 
-class GlueRequestHandler:
+class GlueRequestHandler(ABC):
     def __init__(self, request):
         self.request = request
 
-        self.is_model_object = False
-        self.is_query_set = False
-
         if request.content_type == 'application/json':
             logging.warning(request.body.decode('utf-8'))
             self.body_data = json.loads(request.body.decode('utf-8'))
         else:
             raise Http404
 
+    @abstractmethod
+    def process_response(self):
+        pass
+
+class GlueDataRequestHandler(GlueRequestHandler):
+    def __init__(self, request):
+        super().__init__(request)
+
         self.unique_name = self.body_data['unique_name']
 
         self.glue_session = get_glue_session(request)
@@ -30,6 +37,9 @@ class GlueRequestHandler:
 
         self.method = request.method
 
+        self.is_model_object = False
+        self.is_query_set = False
+
         if self.unique_name in self.context:
             self.model_class = ContentType.objects.get_by_natural_key(
                 self.context[self.unique_name]['app_label'],
@@ -78,32 +88,31 @@ class GlueRequestHandler:
 
     def delete_model_object_handler(self):
         if self.model_object is not None:
-            run_glue_method(self.request, self.model_object, 'django_glue_delete')
+            glue_run_method(self.request, self.model_object, 'django_glue_delete')
 
             if settings.DJANGO_GLUE_AUTO_DELETE:
                 self.model_object.delete()
 
-            return generate_json_response('200',
-                                          'success',
-                                          'Delete Object Success',
-                                          'The object you are trying to delete was completed successful')
+            return generate_json_response(
+                'Delete Object Success',
+                'The object you are trying to delete was completed successful'
+            )
         else:
             return generate_json_404_response()
 
     def query_model_object_handler(self):
         if self.model_object is not None:
-            run_glue_method(self.request, self.model_object, 'django_glue_view')
+            glue_run_method(self.request, self.model_object, 'django_glue_view')
 
-            return generate_json_response('200',
-                                          'success',
-                                          'Retrieve Object Data Success',
-                                          'The object data you are trying to receive was successful',
-                                          additional_data=generate_simple_field_dict(
-                                              self.model_object,
-                                              self.glue_session['fields'][self.unique_name],
-                                              self.glue_session['exclude'][self.unique_name],
-                                          )
-                                          )
+            return generate_json_response(
+                'Retrieve Object Data Success',
+                'The object data you are trying to receive was successful',
+                additional_data=generate_simple_field_dict(
+                    self.model_object,
+                    self.glue_session['fields'][self.unique_name],
+                    self.glue_session['exclude'][self.unique_name],
+                )
+            )
         else:
             return generate_json_404_response()
 
@@ -111,36 +120,45 @@ class GlueRequestHandler:
         new_model_object = self.model_class()
         process_and_save_form_values(new_model_object, self.body_data['data']['form_values'])
 
-        run_glue_method(self.request, new_model_object, 'django_glue_create')
+        glue_run_method(self.request, new_model_object, 'django_glue_create')
 
-        return generate_json_response('200',
-                                      'success',
-                                      'Create Object Success',
-                                      'The thing you tried to create was completely successful',
-                                      additional_data=generate_simple_field_dict(
-                                          new_model_object,
-                                          self.glue_session['fields'][self.unique_name],
-                                          self.glue_session['exclude'][self.unique_name],
-                                      )
-                                      )
+        return generate_json_response(
+            'Create Object Success',
+            'The thing you tried to create was completely successful',
+            additional_data=generate_simple_field_dict(
+                new_model_object,
+                self.glue_session['fields'][self.unique_name],
+                self.glue_session['exclude'][self.unique_name],
+            )
+        )
 
     def put_model_object_handler(self):
         if self.model_object is not None:
 
             if 'form_values' in self.body_data['data']:
-                process_and_save_form_values(self.model_object, self.body_data['data']['form_values'])
+                process_and_save_form_values(
+                    self.model_object,
+                    self.body_data['data']['form_values'],
+                    self.glue_session['fields'][self.unique_name],
+                    self.glue_session['exclude'][self.unique_name],
+                )
 
             elif 'field_name' in self.body_data['data']:
                 if self.body_data['data']['field_name'] in self.context[self.unique_name]['fields']:
-                    process_and_save_field_value(self.model_object, self.body_data['data']['field_name'],
-                                                 self.body_data['data']['value'])
+                    process_and_save_field_value(
+                        self.model_object,
+                        self.body_data['data']['field_name'],
+                        self.body_data['data']['value'],
+                        self.glue_session['fields'][self.unique_name],
+                        self.glue_session['exclude'][self.unique_name],
+                    )
 
-            run_glue_method(self.request, self.model_object, 'django_glue_update')
+            glue_run_method(self.request, self.model_object, 'django_glue_update')
 
-            return generate_json_response('200',
-                                          'success',
-                                          'Update Object Successful',
-                                          'The thing you tried to update was completely successful')
+            return generate_json_response(
+                'Update Object Successful',
+                'The thing you tried to update was completely successful'
+            )
         else:
             return generate_json_404_response()
 
@@ -152,15 +170,15 @@ class GlueRequestHandler:
                 logging.error('Handler: Object not Found')
                 return generate_json_404_response()
 
-            run_glue_method(self.request, model_object, 'django_glue_delete')
+            glue_run_method(self.request, model_object, 'django_glue_delete')
 
             if settings.DJANGO_GLUE_AUTO_DELETE:
                 model_object.delete()
 
-            return generate_json_response('200',
-                                          'success',
-                                          'Delete Object in Query Set Success',
-                                          'The thing you tried to delete was successful')
+            return generate_json_response(
+                'Delete Object in Query Set Success',
+                'The thing you tried to delete was successful'
+            )
         else:
             logging.error('Handler: ID not in Body')
             return generate_json_404_response()
@@ -174,44 +192,48 @@ class GlueRequestHandler:
                 except self.model_class.DoesNotExist:
                     return generate_json_404_response()
 
-                return generate_json_response('200',
-                                              'success',
-                                              'Retrieve Object Data in Query Set Success',
-                                              'The object data in query set you are trying to receive was successful',
-                                              additional_data=generate_simple_field_dict(
-                                                  model_object,
-                                                  self.glue_session['fields'][self.unique_name],
-                                                  self.glue_session['exclude'][self.unique_name],
-                                              )
-                                              )
+                return generate_json_response(
+                    'Retrieve Object Data in Query Set Success',
+                    'The object data in query set you are trying to receive was successful',
+                    additional_data=generate_simple_field_dict(
+                        model_object,
+                        self.glue_session['fields'][self.unique_name],
+                        self.glue_session['exclude'][self.unique_name],
+                    )
+                )
             else:
                 model_object_list = dict()
                 for model_object in self.query_set:
                     model_object_list[model_object.id] = model_to_dict(model_object)
 
-                return generate_json_response('200',
-                                              'success', 'View Query Set Success',
-                                              'The thing you tried to create was completely successful',
-                                              additional_data=model_object_list)
+                return generate_json_response(
+                    'View Query Set Success',
+                    'The thing you tried to create was completely successful',
+                    additional_data=model_object_list
+                )
         else:
             return generate_json_404_response()
 
     def post_query_set_handler(self):
         new_model_object = self.model_class()
-        process_and_save_form_values(new_model_object, self.body_data['data']['form_values'])
+        process_and_save_form_values(
+            new_model_object,
+            self.body_data['data']['form_values'],
+            self.glue_session['fields'][self.unique_name],
+            self.glue_session['exclude'][self.unique_name],
+        )
 
-        run_glue_method(self.request, new_model_object, 'django_glue_create')
+        glue_run_method(self.request, new_model_object, 'django_glue_create')
 
-        return generate_json_response('200',
-                                      'success',
-                                      'Create Object in Queryset Success',
-                                      'The thing you tried to create was completely successful',
-                                      additional_data=generate_simple_field_dict(
-                                          new_model_object,
-                                          self.glue_session['fields'][self.unique_name],
-                                          self.glue_session['exclude'][self.unique_name],
-                                      )
-                                      )
+        return generate_json_response(
+            'Create Object in Queryset Success',
+            'The thing you tried to create was completely successful',
+            additional_data=generate_simple_field_dict(
+                new_model_object,
+                self.glue_session['fields'][self.unique_name],
+                self.glue_session['exclude'][self.unique_name],
+            )
+        )
 
     def put_query_set_handler(self):
         if 'id' in self.body_data['data']:
@@ -221,18 +243,23 @@ class GlueRequestHandler:
                 return generate_json_404_response()
 
             if 'form_values' in self.body_data['data']:
-                process_and_save_form_values(model_object, self.body_data['data']['form_values'])
+                process_and_save_form_values(
+                    model_object,
+                    self.body_data['data']['form_values'],
+                    self.glue_session['fields'][self.unique_name],
+                    self.glue_session['exclude'][self.unique_name],
+                )
 
             elif 'field_name' in self.body_data['data']:
                 if self.body_data['data']['field_name'] in self.context[self.unique_name]['fields']:
                     process_and_save_field_value(model_object, self.body_data['data']['field_name'],
                                                  self.body_data['data']['value'])
 
-            run_glue_method(self.request, model_object, 'django_glue_update')
+            glue_run_method(self.request, model_object, 'django_glue_update')
 
-            return generate_json_response('200',
-                                          'success',
-                                          'Update Successful',
-                                          'The thing you tried to update was completely successful')
+            return generate_json_response(
+                'Update Successful',
+                'The thing you tried to update was completely successful'
+            )
         else:
-            return generate_json_404_response()
+            return generate_json_404_response()
\ No newline at end of file
