@@ -1,7 +1,8 @@
-import logging
-
 from django.urls import resolve
 
+from django_glue.conf import settings
+from django_glue.glue import clean_glue_session
+
 
 class GlueMiddleware(object):
     def __init__(self, get_response):
@@ -13,7 +14,9 @@ class GlueMiddleware(object):
 
     def process_view(self, request, view_func, view_args, view_kwargs):
         current_url = resolve(request.path_info).url_name
+
         if current_url != 'django_glue_handler':
-            request.session['django_glue'] = dict()
+            clean_glue_session(request)
+            request.session[settings.DJANGO_GLUE_SESSION_NAME] = dict()
 
         return None
